# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNatFirewallsResult',
    'AwaitableGetNatFirewallsResult',
    'get_nat_firewalls',
    'get_nat_firewalls_output',
]

@pulumi.output_type
class GetNatFirewallsResult:
    """
    A collection of values returned by getNatFirewalls.
    """
    def __init__(__self__, firewalls=None, id=None, ids=None, lang=None, member_uid=None, nat_gateway_id=None, output_file=None, page_number=None, page_size=None, proxy_id=None, proxy_name=None, region_no=None, status=None, vpc_id=None):
        if firewalls and not isinstance(firewalls, list):
            raise TypeError("Expected argument 'firewalls' to be a list")
        pulumi.set(__self__, "firewalls", firewalls)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if lang and not isinstance(lang, str):
            raise TypeError("Expected argument 'lang' to be a str")
        pulumi.set(__self__, "lang", lang)
        if member_uid and not isinstance(member_uid, int):
            raise TypeError("Expected argument 'member_uid' to be a int")
        pulumi.set(__self__, "member_uid", member_uid)
        if nat_gateway_id and not isinstance(nat_gateway_id, str):
            raise TypeError("Expected argument 'nat_gateway_id' to be a str")
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if proxy_id and not isinstance(proxy_id, str):
            raise TypeError("Expected argument 'proxy_id' to be a str")
        pulumi.set(__self__, "proxy_id", proxy_id)
        if proxy_name and not isinstance(proxy_name, str):
            raise TypeError("Expected argument 'proxy_name' to be a str")
        pulumi.set(__self__, "proxy_name", proxy_name)
        if region_no and not isinstance(region_no, str):
            raise TypeError("Expected argument 'region_no' to be a str")
        pulumi.set(__self__, "region_no", region_no)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def firewalls(self) -> Sequence['outputs.GetNatFirewallsFirewallResult']:
        """
        A list of Nat Firewall Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "firewalls")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Nat Firewall IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def lang(self) -> Optional[builtins.str]:
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> Optional[builtins.int]:
        """
        Member Account ID
        """
        return pulumi.get(self, "member_uid")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[builtins.str]:
        """
        NAT gateway ID
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> Optional[builtins.str]:
        """
        NAT firewall ID
        """
        return pulumi.get(self, "proxy_id")

    @property
    @pulumi.getter(name="proxyName")
    def proxy_name(self) -> Optional[builtins.str]:
        """
        NAT firewall name
        """
        return pulumi.get(self, "proxy_name")

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> Optional[builtins.str]:
        return pulumi.get(self, "region_no")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[builtins.str]:
        """
        The ID of the VPC instance.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNatFirewallsResult(GetNatFirewallsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNatFirewallsResult(
            firewalls=self.firewalls,
            id=self.id,
            ids=self.ids,
            lang=self.lang,
            member_uid=self.member_uid,
            nat_gateway_id=self.nat_gateway_id,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            proxy_id=self.proxy_id,
            proxy_name=self.proxy_name,
            region_no=self.region_no,
            status=self.status,
            vpc_id=self.vpc_id)


def get_nat_firewalls(ids: Optional[Sequence[builtins.str]] = None,
                      lang: Optional[builtins.str] = None,
                      member_uid: Optional[builtins.int] = None,
                      nat_gateway_id: Optional[builtins.str] = None,
                      output_file: Optional[builtins.str] = None,
                      page_number: Optional[builtins.int] = None,
                      page_size: Optional[builtins.int] = None,
                      proxy_id: Optional[builtins.str] = None,
                      proxy_name: Optional[builtins.str] = None,
                      region_no: Optional[builtins.str] = None,
                      status: Optional[builtins.str] = None,
                      vpc_id: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNatFirewallsResult:
    """
    This data source provides Cloud Firewall Nat Firewall available to the user.[What is Nat Firewall](https://next.api.alibabacloud.com/document/Cloudfw/2017-12-07/CreateSecurityProxy)

    > **NOTE:** Available since v1.243.0.


    :param Sequence[builtins.str] ids: A list of Nat Firewall IDs.
    :param builtins.str lang: Lang
    :param builtins.int member_uid: Member Account ID
    :param builtins.str nat_gateway_id: NAT gateway ID
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Page No
    :param builtins.int page_size: Page Size
    :param builtins.str proxy_id: NAT firewall ID
    :param builtins.str proxy_name: NAT firewall name
    :param builtins.str region_no: Region
    :param builtins.str status: The status of the resource
    :param builtins.str vpc_id: The ID of the VPC instance.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['lang'] = lang
    __args__['memberUid'] = member_uid
    __args__['natGatewayId'] = nat_gateway_id
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['proxyId'] = proxy_id
    __args__['proxyName'] = proxy_name
    __args__['regionNo'] = region_no
    __args__['status'] = status
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cloudfirewall/getNatFirewalls:getNatFirewalls', __args__, opts=opts, typ=GetNatFirewallsResult).value

    return AwaitableGetNatFirewallsResult(
        firewalls=pulumi.get(__ret__, 'firewalls'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        lang=pulumi.get(__ret__, 'lang'),
        member_uid=pulumi.get(__ret__, 'member_uid'),
        nat_gateway_id=pulumi.get(__ret__, 'nat_gateway_id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        proxy_id=pulumi.get(__ret__, 'proxy_id'),
        proxy_name=pulumi.get(__ret__, 'proxy_name'),
        region_no=pulumi.get(__ret__, 'region_no'),
        status=pulumi.get(__ret__, 'status'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_nat_firewalls_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                             lang: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             member_uid: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                             nat_gateway_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                             page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                             proxy_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             proxy_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             region_no: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             vpc_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNatFirewallsResult]:
    """
    This data source provides Cloud Firewall Nat Firewall available to the user.[What is Nat Firewall](https://next.api.alibabacloud.com/document/Cloudfw/2017-12-07/CreateSecurityProxy)

    > **NOTE:** Available since v1.243.0.


    :param Sequence[builtins.str] ids: A list of Nat Firewall IDs.
    :param builtins.str lang: Lang
    :param builtins.int member_uid: Member Account ID
    :param builtins.str nat_gateway_id: NAT gateway ID
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.int page_number: Page No
    :param builtins.int page_size: Page Size
    :param builtins.str proxy_id: NAT firewall ID
    :param builtins.str proxy_name: NAT firewall name
    :param builtins.str region_no: Region
    :param builtins.str status: The status of the resource
    :param builtins.str vpc_id: The ID of the VPC instance.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['lang'] = lang
    __args__['memberUid'] = member_uid
    __args__['natGatewayId'] = nat_gateway_id
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['proxyId'] = proxy_id
    __args__['proxyName'] = proxy_name
    __args__['regionNo'] = region_no
    __args__['status'] = status
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cloudfirewall/getNatFirewalls:getNatFirewalls', __args__, opts=opts, typ=GetNatFirewallsResult)
    return __ret__.apply(lambda __response__: GetNatFirewallsResult(
        firewalls=pulumi.get(__response__, 'firewalls'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        lang=pulumi.get(__response__, 'lang'),
        member_uid=pulumi.get(__response__, 'member_uid'),
        nat_gateway_id=pulumi.get(__response__, 'nat_gateway_id'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        proxy_id=pulumi.get(__response__, 'proxy_id'),
        proxy_name=pulumi.get(__response__, 'proxy_name'),
        region_no=pulumi.get(__response__, 'region_no'),
        status=pulumi.get(__response__, 'status'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CasterArgs', 'Caster']

@pulumi.input_type
class CasterArgs:
    def __init__(__self__, *,
                 norm_type: pulumi.Input[builtins.int],
                 payment_type: pulumi.Input[builtins.str],
                 auto_switch_urgent_config: Optional[pulumi.Input[builtins.str]] = None,
                 auto_switch_urgent_on: Optional[pulumi.Input[builtins.bool]] = None,
                 callback_url: Optional[pulumi.Input[builtins.str]] = None,
                 caster_name: Optional[pulumi.Input[builtins.str]] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 program_effect: Optional[pulumi.Input[builtins.int]] = None,
                 program_name: Optional[pulumi.Input[builtins.str]] = None,
                 record_config: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url_list: Optional[pulumi.Input[builtins.str]] = None,
                 sync_groups_config: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transcode_config: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_id: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_live_stream_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_material_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Caster resource.
        :param pulumi.Input[builtins.int] norm_type: Guide station specification type. Value:
               - 0: Broadcast single type.
               - 1: General purpose.
        :param pulumi.Input[builtins.str] payment_type: The paymen type of the resource
        :param pulumi.Input[builtins.str] auto_switch_urgent_config: Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        :param pulumi.Input[builtins.bool] auto_switch_urgent_on: Turn on the cut-off automatic switch for broadcast preparation.
               
               true: open.
               
               false: closed.
        :param pulumi.Input[builtins.str] callback_url: The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        :param pulumi.Input[builtins.str] caster_name: Guide station name.
        :param pulumi.Input[builtins.float] delay: Delayed playback. Time unit: seconds.
        :param pulumi.Input[builtins.str] domain_name: Master play domain name.
        :param pulumi.Input[builtins.int] program_effect: Carousel effective flag.
               
               0: Not in effect.
               
               1: Entry into force.
        :param pulumi.Input[builtins.str] program_name: The carousel station name, which can be configured when using the carousel function.
        :param pulumi.Input[builtins.str] record_config: Record configuration information. The format is JSON. The configuration element information is as follows:
        :param pulumi.Input[builtins.str] resource_group_id: Resource Group id
        :param pulumi.Input[builtins.str] resource_type: resource type
        :param pulumi.Input[builtins.str] side_output_url: The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        :param pulumi.Input[builtins.str] side_output_url_list: The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        :param pulumi.Input[builtins.str] sync_groups_config: Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
               - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
               - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
               - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
               - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transcode_config: Transcoding configuration.
               
               JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        :param pulumi.Input[builtins.str] urgent_image_id: The ID of the picture material of the media library.
        :param pulumi.Input[builtins.str] urgent_image_url: Prepare the URL of the picture material.
        :param pulumi.Input[builtins.str] urgent_live_stream_url: The prepared live stream URL.
        :param pulumi.Input[builtins.str] urgent_material_id: Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        pulumi.set(__self__, "norm_type", norm_type)
        pulumi.set(__self__, "payment_type", payment_type)
        if auto_switch_urgent_config is not None:
            pulumi.set(__self__, "auto_switch_urgent_config", auto_switch_urgent_config)
        if auto_switch_urgent_on is not None:
            pulumi.set(__self__, "auto_switch_urgent_on", auto_switch_urgent_on)
        if callback_url is not None:
            pulumi.set(__self__, "callback_url", callback_url)
        if caster_name is not None:
            pulumi.set(__self__, "caster_name", caster_name)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if program_effect is not None:
            pulumi.set(__self__, "program_effect", program_effect)
        if program_name is not None:
            pulumi.set(__self__, "program_name", program_name)
        if record_config is not None:
            pulumi.set(__self__, "record_config", record_config)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if side_output_url is not None:
            pulumi.set(__self__, "side_output_url", side_output_url)
        if side_output_url_list is not None:
            pulumi.set(__self__, "side_output_url_list", side_output_url_list)
        if sync_groups_config is not None:
            pulumi.set(__self__, "sync_groups_config", sync_groups_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transcode_config is not None:
            pulumi.set(__self__, "transcode_config", transcode_config)
        if urgent_image_id is not None:
            pulumi.set(__self__, "urgent_image_id", urgent_image_id)
        if urgent_image_url is not None:
            pulumi.set(__self__, "urgent_image_url", urgent_image_url)
        if urgent_live_stream_url is not None:
            pulumi.set(__self__, "urgent_live_stream_url", urgent_live_stream_url)
        if urgent_material_id is not None:
            pulumi.set(__self__, "urgent_material_id", urgent_material_id)

    @property
    @pulumi.getter(name="normType")
    def norm_type(self) -> pulumi.Input[builtins.int]:
        """
        Guide station specification type. Value:
        - 0: Broadcast single type.
        - 1: General purpose.
        """
        return pulumi.get(self, "norm_type")

    @norm_type.setter
    def norm_type(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "norm_type", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[builtins.str]:
        """
        The paymen type of the resource
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="autoSwitchUrgentConfig")
    def auto_switch_urgent_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        """
        return pulumi.get(self, "auto_switch_urgent_config")

    @auto_switch_urgent_config.setter
    def auto_switch_urgent_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_switch_urgent_config", value)

    @property
    @pulumi.getter(name="autoSwitchUrgentOn")
    def auto_switch_urgent_on(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Turn on the cut-off automatic switch for broadcast preparation.

        true: open.

        false: closed.
        """
        return pulumi.get(self, "auto_switch_urgent_on")

    @auto_switch_urgent_on.setter
    def auto_switch_urgent_on(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_switch_urgent_on", value)

    @property
    @pulumi.getter(name="callbackUrl")
    def callback_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        """
        return pulumi.get(self, "callback_url")

    @callback_url.setter
    def callback_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "callback_url", value)

    @property
    @pulumi.getter(name="casterName")
    def caster_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Guide station name.
        """
        return pulumi.get(self, "caster_name")

    @caster_name.setter
    def caster_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "caster_name", value)

    @property
    @pulumi.getter
    def delay(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Delayed playback. Time unit: seconds.
        """
        return pulumi.get(self, "delay")

    @delay.setter
    def delay(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "delay", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Master play domain name.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="programEffect")
    def program_effect(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Carousel effective flag.

        0: Not in effect.

        1: Entry into force.
        """
        return pulumi.get(self, "program_effect")

    @program_effect.setter
    def program_effect(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "program_effect", value)

    @property
    @pulumi.getter(name="programName")
    def program_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The carousel station name, which can be configured when using the carousel function.
        """
        return pulumi.get(self, "program_name")

    @program_name.setter
    def program_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "program_name", value)

    @property
    @pulumi.getter(name="recordConfig")
    def record_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Record configuration information. The format is JSON. The configuration element information is as follows:
        """
        return pulumi.get(self, "record_config")

    @record_config.setter
    def record_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "record_config", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource Group id
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        resource type
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="sideOutputUrl")
    def side_output_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        """
        return pulumi.get(self, "side_output_url")

    @side_output_url.setter
    def side_output_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "side_output_url", value)

    @property
    @pulumi.getter(name="sideOutputUrlList")
    def side_output_url_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        """
        return pulumi.get(self, "side_output_url_list")

    @side_output_url_list.setter
    def side_output_url_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "side_output_url_list", value)

    @property
    @pulumi.getter(name="syncGroupsConfig")
    def sync_groups_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
        - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
        - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
        - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
        - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        """
        return pulumi.get(self, "sync_groups_config")

    @sync_groups_config.setter
    def sync_groups_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sync_groups_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transcodeConfig")
    def transcode_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Transcoding configuration.

        JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        """
        return pulumi.get(self, "transcode_config")

    @transcode_config.setter
    def transcode_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transcode_config", value)

    @property
    @pulumi.getter(name="urgentImageId")
    def urgent_image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the picture material of the media library.
        """
        return pulumi.get(self, "urgent_image_id")

    @urgent_image_id.setter
    def urgent_image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_image_id", value)

    @property
    @pulumi.getter(name="urgentImageUrl")
    def urgent_image_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Prepare the URL of the picture material.
        """
        return pulumi.get(self, "urgent_image_url")

    @urgent_image_url.setter
    def urgent_image_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_image_url", value)

    @property
    @pulumi.getter(name="urgentLiveStreamUrl")
    def urgent_live_stream_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The prepared live stream URL.
        """
        return pulumi.get(self, "urgent_live_stream_url")

    @urgent_live_stream_url.setter
    def urgent_live_stream_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_live_stream_url", value)

    @property
    @pulumi.getter(name="urgentMaterialId")
    def urgent_material_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        return pulumi.get(self, "urgent_material_id")

    @urgent_material_id.setter
    def urgent_material_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_material_id", value)


@pulumi.input_type
class _CasterState:
    def __init__(__self__, *,
                 auto_switch_urgent_config: Optional[pulumi.Input[builtins.str]] = None,
                 auto_switch_urgent_on: Optional[pulumi.Input[builtins.bool]] = None,
                 callback_url: Optional[pulumi.Input[builtins.str]] = None,
                 caster_name: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 norm_type: Optional[pulumi.Input[builtins.int]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 program_effect: Optional[pulumi.Input[builtins.int]] = None,
                 program_name: Optional[pulumi.Input[builtins.str]] = None,
                 record_config: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url_list: Optional[pulumi.Input[builtins.str]] = None,
                 sync_groups_config: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transcode_config: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_id: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_live_stream_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_material_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Caster resources.
        :param pulumi.Input[builtins.str] auto_switch_urgent_config: Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        :param pulumi.Input[builtins.bool] auto_switch_urgent_on: Turn on the cut-off automatic switch for broadcast preparation.
               
               true: open.
               
               false: closed.
        :param pulumi.Input[builtins.str] callback_url: The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        :param pulumi.Input[builtins.str] caster_name: Guide station name.
        :param pulumi.Input[builtins.str] create_time: Creation time.
        :param pulumi.Input[builtins.float] delay: Delayed playback. Time unit: seconds.
        :param pulumi.Input[builtins.str] domain_name: Master play domain name.
        :param pulumi.Input[builtins.int] norm_type: Guide station specification type. Value:
               - 0: Broadcast single type.
               - 1: General purpose.
        :param pulumi.Input[builtins.str] payment_type: The paymen type of the resource
        :param pulumi.Input[builtins.int] program_effect: Carousel effective flag.
               
               0: Not in effect.
               
               1: Entry into force.
        :param pulumi.Input[builtins.str] program_name: The carousel station name, which can be configured when using the carousel function.
        :param pulumi.Input[builtins.str] record_config: Record configuration information. The format is JSON. The configuration element information is as follows:
        :param pulumi.Input[builtins.str] resource_group_id: Resource Group id
        :param pulumi.Input[builtins.str] resource_type: resource type
        :param pulumi.Input[builtins.str] side_output_url: The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        :param pulumi.Input[builtins.str] side_output_url_list: The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        :param pulumi.Input[builtins.str] sync_groups_config: Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
               - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
               - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
               - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
               - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transcode_config: Transcoding configuration.
               
               JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        :param pulumi.Input[builtins.str] urgent_image_id: The ID of the picture material of the media library.
        :param pulumi.Input[builtins.str] urgent_image_url: Prepare the URL of the picture material.
        :param pulumi.Input[builtins.str] urgent_live_stream_url: The prepared live stream URL.
        :param pulumi.Input[builtins.str] urgent_material_id: Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        if auto_switch_urgent_config is not None:
            pulumi.set(__self__, "auto_switch_urgent_config", auto_switch_urgent_config)
        if auto_switch_urgent_on is not None:
            pulumi.set(__self__, "auto_switch_urgent_on", auto_switch_urgent_on)
        if callback_url is not None:
            pulumi.set(__self__, "callback_url", callback_url)
        if caster_name is not None:
            pulumi.set(__self__, "caster_name", caster_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if delay is not None:
            pulumi.set(__self__, "delay", delay)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if norm_type is not None:
            pulumi.set(__self__, "norm_type", norm_type)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if program_effect is not None:
            pulumi.set(__self__, "program_effect", program_effect)
        if program_name is not None:
            pulumi.set(__self__, "program_name", program_name)
        if record_config is not None:
            pulumi.set(__self__, "record_config", record_config)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if side_output_url is not None:
            pulumi.set(__self__, "side_output_url", side_output_url)
        if side_output_url_list is not None:
            pulumi.set(__self__, "side_output_url_list", side_output_url_list)
        if sync_groups_config is not None:
            pulumi.set(__self__, "sync_groups_config", sync_groups_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transcode_config is not None:
            pulumi.set(__self__, "transcode_config", transcode_config)
        if urgent_image_id is not None:
            pulumi.set(__self__, "urgent_image_id", urgent_image_id)
        if urgent_image_url is not None:
            pulumi.set(__self__, "urgent_image_url", urgent_image_url)
        if urgent_live_stream_url is not None:
            pulumi.set(__self__, "urgent_live_stream_url", urgent_live_stream_url)
        if urgent_material_id is not None:
            pulumi.set(__self__, "urgent_material_id", urgent_material_id)

    @property
    @pulumi.getter(name="autoSwitchUrgentConfig")
    def auto_switch_urgent_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        """
        return pulumi.get(self, "auto_switch_urgent_config")

    @auto_switch_urgent_config.setter
    def auto_switch_urgent_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auto_switch_urgent_config", value)

    @property
    @pulumi.getter(name="autoSwitchUrgentOn")
    def auto_switch_urgent_on(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Turn on the cut-off automatic switch for broadcast preparation.

        true: open.

        false: closed.
        """
        return pulumi.get(self, "auto_switch_urgent_on")

    @auto_switch_urgent_on.setter
    def auto_switch_urgent_on(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_switch_urgent_on", value)

    @property
    @pulumi.getter(name="callbackUrl")
    def callback_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        """
        return pulumi.get(self, "callback_url")

    @callback_url.setter
    def callback_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "callback_url", value)

    @property
    @pulumi.getter(name="casterName")
    def caster_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Guide station name.
        """
        return pulumi.get(self, "caster_name")

    @caster_name.setter
    def caster_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "caster_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def delay(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Delayed playback. Time unit: seconds.
        """
        return pulumi.get(self, "delay")

    @delay.setter
    def delay(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "delay", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Master play domain name.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="normType")
    def norm_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Guide station specification type. Value:
        - 0: Broadcast single type.
        - 1: General purpose.
        """
        return pulumi.get(self, "norm_type")

    @norm_type.setter
    def norm_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "norm_type", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The paymen type of the resource
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="programEffect")
    def program_effect(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Carousel effective flag.

        0: Not in effect.

        1: Entry into force.
        """
        return pulumi.get(self, "program_effect")

    @program_effect.setter
    def program_effect(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "program_effect", value)

    @property
    @pulumi.getter(name="programName")
    def program_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The carousel station name, which can be configured when using the carousel function.
        """
        return pulumi.get(self, "program_name")

    @program_name.setter
    def program_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "program_name", value)

    @property
    @pulumi.getter(name="recordConfig")
    def record_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Record configuration information. The format is JSON. The configuration element information is as follows:
        """
        return pulumi.get(self, "record_config")

    @record_config.setter
    def record_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "record_config", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource Group id
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        resource type
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="sideOutputUrl")
    def side_output_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        """
        return pulumi.get(self, "side_output_url")

    @side_output_url.setter
    def side_output_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "side_output_url", value)

    @property
    @pulumi.getter(name="sideOutputUrlList")
    def side_output_url_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        """
        return pulumi.get(self, "side_output_url_list")

    @side_output_url_list.setter
    def side_output_url_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "side_output_url_list", value)

    @property
    @pulumi.getter(name="syncGroupsConfig")
    def sync_groups_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
        - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
        - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
        - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
        - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        """
        return pulumi.get(self, "sync_groups_config")

    @sync_groups_config.setter
    def sync_groups_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sync_groups_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transcodeConfig")
    def transcode_config(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Transcoding configuration.

        JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        """
        return pulumi.get(self, "transcode_config")

    @transcode_config.setter
    def transcode_config(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transcode_config", value)

    @property
    @pulumi.getter(name="urgentImageId")
    def urgent_image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the picture material of the media library.
        """
        return pulumi.get(self, "urgent_image_id")

    @urgent_image_id.setter
    def urgent_image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_image_id", value)

    @property
    @pulumi.getter(name="urgentImageUrl")
    def urgent_image_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Prepare the URL of the picture material.
        """
        return pulumi.get(self, "urgent_image_url")

    @urgent_image_url.setter
    def urgent_image_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_image_url", value)

    @property
    @pulumi.getter(name="urgentLiveStreamUrl")
    def urgent_live_stream_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The prepared live stream URL.
        """
        return pulumi.get(self, "urgent_live_stream_url")

    @urgent_live_stream_url.setter
    def urgent_live_stream_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_live_stream_url", value)

    @property
    @pulumi.getter(name="urgentMaterialId")
    def urgent_material_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        return pulumi.get(self, "urgent_material_id")

    @urgent_material_id.setter
    def urgent_material_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urgent_material_id", value)


@pulumi.type_token("alicloud:live/caster:Caster")
class Caster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_switch_urgent_config: Optional[pulumi.Input[builtins.str]] = None,
                 auto_switch_urgent_on: Optional[pulumi.Input[builtins.bool]] = None,
                 callback_url: Optional[pulumi.Input[builtins.str]] = None,
                 caster_name: Optional[pulumi.Input[builtins.str]] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 norm_type: Optional[pulumi.Input[builtins.int]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 program_effect: Optional[pulumi.Input[builtins.int]] = None,
                 program_name: Optional[pulumi.Input[builtins.str]] = None,
                 record_config: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url_list: Optional[pulumi.Input[builtins.str]] = None,
                 sync_groups_config: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transcode_config: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_id: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_live_stream_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_material_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Live Caster resource.

        Relying on Alibaba Cloud's powerful technologies such as live video broadcasting, media processing, and video AI, cloud guide integrates capabilities such as graphic packaging, real-time keying, multi-language translation, and multi-channel mixed streaming to innovate traditional guide services in the cloud. Provide easy-to-use cloud-based guide services for event performances, news reports, live events, off-site broadcasts and other scenes, without hardware, reduce user guide costs, and create a better live broadcast experience.

        For information about Live Caster and how to use it, see [What is Caster](https://www.alibabacloud.com/help/en/live/developer-reference/api-live-2016-11-01-createcaster).

        > **NOTE:** Available since v1.238.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.live.Caster("default",
            caster_name=name,
            payment_type="PayAsYouGo",
            norm_type=1)
        ```

        ## Import

        Live Caster can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:live/caster:Caster example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auto_switch_urgent_config: Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        :param pulumi.Input[builtins.bool] auto_switch_urgent_on: Turn on the cut-off automatic switch for broadcast preparation.
               
               true: open.
               
               false: closed.
        :param pulumi.Input[builtins.str] callback_url: The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        :param pulumi.Input[builtins.str] caster_name: Guide station name.
        :param pulumi.Input[builtins.float] delay: Delayed playback. Time unit: seconds.
        :param pulumi.Input[builtins.str] domain_name: Master play domain name.
        :param pulumi.Input[builtins.int] norm_type: Guide station specification type. Value:
               - 0: Broadcast single type.
               - 1: General purpose.
        :param pulumi.Input[builtins.str] payment_type: The paymen type of the resource
        :param pulumi.Input[builtins.int] program_effect: Carousel effective flag.
               
               0: Not in effect.
               
               1: Entry into force.
        :param pulumi.Input[builtins.str] program_name: The carousel station name, which can be configured when using the carousel function.
        :param pulumi.Input[builtins.str] record_config: Record configuration information. The format is JSON. The configuration element information is as follows:
        :param pulumi.Input[builtins.str] resource_group_id: Resource Group id
        :param pulumi.Input[builtins.str] resource_type: resource type
        :param pulumi.Input[builtins.str] side_output_url: The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        :param pulumi.Input[builtins.str] side_output_url_list: The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        :param pulumi.Input[builtins.str] sync_groups_config: Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
               - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
               - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
               - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
               - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transcode_config: Transcoding configuration.
               
               JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        :param pulumi.Input[builtins.str] urgent_image_id: The ID of the picture material of the media library.
        :param pulumi.Input[builtins.str] urgent_image_url: Prepare the URL of the picture material.
        :param pulumi.Input[builtins.str] urgent_live_stream_url: The prepared live stream URL.
        :param pulumi.Input[builtins.str] urgent_material_id: Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CasterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Live Caster resource.

        Relying on Alibaba Cloud's powerful technologies such as live video broadcasting, media processing, and video AI, cloud guide integrates capabilities such as graphic packaging, real-time keying, multi-language translation, and multi-channel mixed streaming to innovate traditional guide services in the cloud. Provide easy-to-use cloud-based guide services for event performances, news reports, live events, off-site broadcasts and other scenes, without hardware, reduce user guide costs, and create a better live broadcast experience.

        For information about Live Caster and how to use it, see [What is Caster](https://www.alibabacloud.com/help/en/live/developer-reference/api-live-2016-11-01-createcaster).

        > **NOTE:** Available since v1.238.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.live.Caster("default",
            caster_name=name,
            payment_type="PayAsYouGo",
            norm_type=1)
        ```

        ## Import

        Live Caster can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:live/caster:Caster example <id>
        ```

        :param str resource_name: The name of the resource.
        :param CasterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CasterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_switch_urgent_config: Optional[pulumi.Input[builtins.str]] = None,
                 auto_switch_urgent_on: Optional[pulumi.Input[builtins.bool]] = None,
                 callback_url: Optional[pulumi.Input[builtins.str]] = None,
                 caster_name: Optional[pulumi.Input[builtins.str]] = None,
                 delay: Optional[pulumi.Input[builtins.float]] = None,
                 domain_name: Optional[pulumi.Input[builtins.str]] = None,
                 norm_type: Optional[pulumi.Input[builtins.int]] = None,
                 payment_type: Optional[pulumi.Input[builtins.str]] = None,
                 program_effect: Optional[pulumi.Input[builtins.int]] = None,
                 program_name: Optional[pulumi.Input[builtins.str]] = None,
                 record_config: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url: Optional[pulumi.Input[builtins.str]] = None,
                 side_output_url_list: Optional[pulumi.Input[builtins.str]] = None,
                 sync_groups_config: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 transcode_config: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_id: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_image_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_live_stream_url: Optional[pulumi.Input[builtins.str]] = None,
                 urgent_material_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CasterArgs.__new__(CasterArgs)

            __props__.__dict__["auto_switch_urgent_config"] = auto_switch_urgent_config
            __props__.__dict__["auto_switch_urgent_on"] = auto_switch_urgent_on
            __props__.__dict__["callback_url"] = callback_url
            __props__.__dict__["caster_name"] = caster_name
            __props__.__dict__["delay"] = delay
            __props__.__dict__["domain_name"] = domain_name
            if norm_type is None and not opts.urn:
                raise TypeError("Missing required property 'norm_type'")
            __props__.__dict__["norm_type"] = norm_type
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["program_effect"] = program_effect
            __props__.__dict__["program_name"] = program_name
            __props__.__dict__["record_config"] = record_config
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["resource_type"] = resource_type
            __props__.__dict__["side_output_url"] = side_output_url
            __props__.__dict__["side_output_url_list"] = side_output_url_list
            __props__.__dict__["sync_groups_config"] = sync_groups_config
            __props__.__dict__["tags"] = tags
            __props__.__dict__["transcode_config"] = transcode_config
            __props__.__dict__["urgent_image_id"] = urgent_image_id
            __props__.__dict__["urgent_image_url"] = urgent_image_url
            __props__.__dict__["urgent_live_stream_url"] = urgent_live_stream_url
            __props__.__dict__["urgent_material_id"] = urgent_material_id
            __props__.__dict__["create_time"] = None
        super(Caster, __self__).__init__(
            'alicloud:live/caster:Caster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_switch_urgent_config: Optional[pulumi.Input[builtins.str]] = None,
            auto_switch_urgent_on: Optional[pulumi.Input[builtins.bool]] = None,
            callback_url: Optional[pulumi.Input[builtins.str]] = None,
            caster_name: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            delay: Optional[pulumi.Input[builtins.float]] = None,
            domain_name: Optional[pulumi.Input[builtins.str]] = None,
            norm_type: Optional[pulumi.Input[builtins.int]] = None,
            payment_type: Optional[pulumi.Input[builtins.str]] = None,
            program_effect: Optional[pulumi.Input[builtins.int]] = None,
            program_name: Optional[pulumi.Input[builtins.str]] = None,
            record_config: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            side_output_url: Optional[pulumi.Input[builtins.str]] = None,
            side_output_url_list: Optional[pulumi.Input[builtins.str]] = None,
            sync_groups_config: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            transcode_config: Optional[pulumi.Input[builtins.str]] = None,
            urgent_image_id: Optional[pulumi.Input[builtins.str]] = None,
            urgent_image_url: Optional[pulumi.Input[builtins.str]] = None,
            urgent_live_stream_url: Optional[pulumi.Input[builtins.str]] = None,
            urgent_material_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Caster':
        """
        Get an existing Caster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auto_switch_urgent_config: Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        :param pulumi.Input[builtins.bool] auto_switch_urgent_on: Turn on the cut-off automatic switch for broadcast preparation.
               
               true: open.
               
               false: closed.
        :param pulumi.Input[builtins.str] callback_url: The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        :param pulumi.Input[builtins.str] caster_name: Guide station name.
        :param pulumi.Input[builtins.str] create_time: Creation time.
        :param pulumi.Input[builtins.float] delay: Delayed playback. Time unit: seconds.
        :param pulumi.Input[builtins.str] domain_name: Master play domain name.
        :param pulumi.Input[builtins.int] norm_type: Guide station specification type. Value:
               - 0: Broadcast single type.
               - 1: General purpose.
        :param pulumi.Input[builtins.str] payment_type: The paymen type of the resource
        :param pulumi.Input[builtins.int] program_effect: Carousel effective flag.
               
               0: Not in effect.
               
               1: Entry into force.
        :param pulumi.Input[builtins.str] program_name: The carousel station name, which can be configured when using the carousel function.
        :param pulumi.Input[builtins.str] record_config: Record configuration information. The format is JSON. The configuration element information is as follows:
        :param pulumi.Input[builtins.str] resource_group_id: Resource Group id
        :param pulumi.Input[builtins.str] resource_type: resource type
        :param pulumi.Input[builtins.str] side_output_url: The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        :param pulumi.Input[builtins.str] side_output_url_list: The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        :param pulumi.Input[builtins.str] sync_groups_config: Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
               - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
               - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
               - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
               - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] transcode_config: Transcoding configuration.
               
               JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        :param pulumi.Input[builtins.str] urgent_image_id: The ID of the picture material of the media library.
        :param pulumi.Input[builtins.str] urgent_image_url: Prepare the URL of the picture material.
        :param pulumi.Input[builtins.str] urgent_live_stream_url: The prepared live stream URL.
        :param pulumi.Input[builtins.str] urgent_material_id: Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CasterState.__new__(_CasterState)

        __props__.__dict__["auto_switch_urgent_config"] = auto_switch_urgent_config
        __props__.__dict__["auto_switch_urgent_on"] = auto_switch_urgent_on
        __props__.__dict__["callback_url"] = callback_url
        __props__.__dict__["caster_name"] = caster_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["delay"] = delay
        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["norm_type"] = norm_type
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["program_effect"] = program_effect
        __props__.__dict__["program_name"] = program_name
        __props__.__dict__["record_config"] = record_config
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["side_output_url"] = side_output_url
        __props__.__dict__["side_output_url_list"] = side_output_url_list
        __props__.__dict__["sync_groups_config"] = sync_groups_config
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transcode_config"] = transcode_config
        __props__.__dict__["urgent_image_id"] = urgent_image_id
        __props__.__dict__["urgent_image_url"] = urgent_image_url
        __props__.__dict__["urgent_live_stream_url"] = urgent_live_stream_url
        __props__.__dict__["urgent_material_id"] = urgent_material_id
        return Caster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoSwitchUrgentConfig")
    def auto_switch_urgent_config(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Automatic standby broadcast configuration. eofThres: indicates that the broadcast is automatically cut and prepared after the flow interruption time, in seconds.
        """
        return pulumi.get(self, "auto_switch_urgent_config")

    @property
    @pulumi.getter(name="autoSwitchUrgentOn")
    def auto_switch_urgent_on(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Turn on the cut-off automatic switch for broadcast preparation.

        true: open.

        false: closed.
        """
        return pulumi.get(self, "auto_switch_urgent_on")

    @property
    @pulumi.getter(name="callbackUrl")
    def callback_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The callback address of the user. To receive Callback Notifications, enter an available address and accept the HTTP protocol. If this parameter is set to null, the callback notification from the director Station is canceled by default.
        """
        return pulumi.get(self, "callback_url")

    @property
    @pulumi.getter(name="casterName")
    def caster_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Guide station name.
        """
        return pulumi.get(self, "caster_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def delay(self) -> pulumi.Output[Optional[builtins.float]]:
        """
        Delayed playback. Time unit: seconds.
        """
        return pulumi.get(self, "delay")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Master play domain name.
        """
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter(name="normType")
    def norm_type(self) -> pulumi.Output[builtins.int]:
        """
        Guide station specification type. Value:
        - 0: Broadcast single type.
        - 1: General purpose.
        """
        return pulumi.get(self, "norm_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[builtins.str]:
        """
        The paymen type of the resource
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="programEffect")
    def program_effect(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Carousel effective flag.

        0: Not in effect.

        1: Entry into force.
        """
        return pulumi.get(self, "program_effect")

    @property
    @pulumi.getter(name="programName")
    def program_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The carousel station name, which can be configured when using the carousel function.
        """
        return pulumi.get(self, "program_name")

    @property
    @pulumi.getter(name="recordConfig")
    def record_config(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Record configuration information. The format is JSON. The configuration element information is as follows:
        """
        return pulumi.get(self, "record_config")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        Resource Group id
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        resource type
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="sideOutputUrl")
    def side_output_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The user-defined stream ingest address corresponding to the bypass output address of the guide station. If this parameter is left blank, the streaming address corresponding to the output address automatically generated by Alibaba Cloud is used by default.
        """
        return pulumi.get(self, "side_output_url")

    @property
    @pulumi.getter(name="sideOutputUrlList")
    def side_output_url_list(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The list of multiple forwarding stream addresses, which can be the CDN forwarding stream addresses of Alibaba Cloud or a third-party vendor. A guide can add up to 20 RTMP forwarding addresses.
        """
        return pulumi.get(self, "side_output_url_list")

    @property
    @pulumi.getter(name="syncGroupsConfig")
    def sync_groups_config(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Multi-View synchronization configuration to synchronize multiple video sources. Multi-View synchronization is divided into two modes:
        - `mode 0`: (In the anchor mode, multiple video sources are synchronized according to the specified mode.)
        - `mode 1`: (Conference mode, there is no concept of anchor video, all video sources are synchronized with each other.)
        - `Anchor mode`: hostResourceId: the video source of the anchor in Anchor mode.
        - `Conference mode`: no hostRsoureId field, only the resource ids in the resourceIds to be provided.
        """
        return pulumi.get(self, "sync_groups_config")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transcodeConfig")
    def transcode_config(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Transcoding configuration.

        JSON format string, Please capitalize the first letter of the internal field of the structure, hump format input. If this parameter is set to null, the transcoding configuration is cleared by default. If the transcoding template is null, an error is reported when the director starts.
        """
        return pulumi.get(self, "transcode_config")

    @property
    @pulumi.getter(name="urgentImageId")
    def urgent_image_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the picture material of the media library.
        """
        return pulumi.get(self, "urgent_image_id")

    @property
    @pulumi.getter(name="urgentImageUrl")
    def urgent_image_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Prepare the URL of the picture material.
        """
        return pulumi.get(self, "urgent_image_url")

    @property
    @pulumi.getter(name="urgentLiveStreamUrl")
    def urgent_live_stream_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The prepared live stream URL.
        """
        return pulumi.get(self, "urgent_live_stream_url")

    @property
    @pulumi.getter(name="urgentMaterialId")
    def urgent_material_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Prepared video, media library material ID. If this parameter is set to null, the standby configuration is cleared by default.
        """
        return pulumi.get(self, "urgent_material_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DiAlarmRuleNotificationSettingsArgs',
    'DiAlarmRuleNotificationSettingsArgsDict',
    'DiAlarmRuleNotificationSettingsNotificationChannelArgs',
    'DiAlarmRuleNotificationSettingsNotificationChannelArgsDict',
    'DiAlarmRuleNotificationSettingsNotificationReceiverArgs',
    'DiAlarmRuleNotificationSettingsNotificationReceiverArgsDict',
    'DiAlarmRuleTriggerConditionArgs',
    'DiAlarmRuleTriggerConditionArgsDict',
    'DiJobDestinationDataSourceSettingArgs',
    'DiJobDestinationDataSourceSettingArgsDict',
    'DiJobJobSettingsArgs',
    'DiJobJobSettingsArgsDict',
    'DiJobJobSettingsColumnDataTypeSettingArgs',
    'DiJobJobSettingsColumnDataTypeSettingArgsDict',
    'DiJobJobSettingsCycleScheduleSettingsArgs',
    'DiJobJobSettingsCycleScheduleSettingsArgsDict',
    'DiJobJobSettingsDdlHandlingSettingArgs',
    'DiJobJobSettingsDdlHandlingSettingArgsDict',
    'DiJobJobSettingsRuntimeSettingArgs',
    'DiJobJobSettingsRuntimeSettingArgsDict',
    'DiJobResourceSettingsArgs',
    'DiJobResourceSettingsArgsDict',
    'DiJobResourceSettingsOfflineResourceSettingsArgs',
    'DiJobResourceSettingsOfflineResourceSettingsArgsDict',
    'DiJobResourceSettingsRealtimeResourceSettingsArgs',
    'DiJobResourceSettingsRealtimeResourceSettingsArgsDict',
    'DiJobResourceSettingsScheduleResourceSettingsArgs',
    'DiJobResourceSettingsScheduleResourceSettingsArgsDict',
    'DiJobSourceDataSourceSettingArgs',
    'DiJobSourceDataSourceSettingArgsDict',
    'DiJobSourceDataSourceSettingDataSourcePropertiesArgs',
    'DiJobSourceDataSourceSettingDataSourcePropertiesArgsDict',
    'DiJobTableMappingArgs',
    'DiJobTableMappingArgsDict',
    'DiJobTableMappingSourceObjectSelectionRuleArgs',
    'DiJobTableMappingSourceObjectSelectionRuleArgsDict',
    'DiJobTableMappingTransformationRuleArgs',
    'DiJobTableMappingTransformationRuleArgsDict',
    'DiJobTransformationRuleArgs',
    'DiJobTransformationRuleArgsDict',
    'ProjectMemberRoleArgs',
    'ProjectMemberRoleArgsDict',
]

MYPY = False

if not MYPY:
    class DiAlarmRuleNotificationSettingsArgsDict(TypedDict):
        inhibition_interval: NotRequired[pulumi.Input[builtins.int]]
        """
        Alarm suppression interval, in minutes
        """
        notification_channels: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationChannelArgsDict']]]]
        """
        Alarm notification Channel See `notification_channels` below.
        """
        notification_receivers: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationReceiverArgsDict']]]]
        """
        List of alert notification recipients See `notification_receivers` below.
        """
elif False:
    DiAlarmRuleNotificationSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiAlarmRuleNotificationSettingsArgs:
    def __init__(__self__, *,
                 inhibition_interval: Optional[pulumi.Input[builtins.int]] = None,
                 notification_channels: Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationChannelArgs']]]] = None,
                 notification_receivers: Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationReceiverArgs']]]] = None):
        """
        :param pulumi.Input[builtins.int] inhibition_interval: Alarm suppression interval, in minutes
        :param pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationChannelArgs']]] notification_channels: Alarm notification Channel See `notification_channels` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationReceiverArgs']]] notification_receivers: List of alert notification recipients See `notification_receivers` below.
        """
        if inhibition_interval is not None:
            pulumi.set(__self__, "inhibition_interval", inhibition_interval)
        if notification_channels is not None:
            pulumi.set(__self__, "notification_channels", notification_channels)
        if notification_receivers is not None:
            pulumi.set(__self__, "notification_receivers", notification_receivers)

    @property
    @pulumi.getter(name="inhibitionInterval")
    def inhibition_interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Alarm suppression interval, in minutes
        """
        return pulumi.get(self, "inhibition_interval")

    @inhibition_interval.setter
    def inhibition_interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "inhibition_interval", value)

    @property
    @pulumi.getter(name="notificationChannels")
    def notification_channels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationChannelArgs']]]]:
        """
        Alarm notification Channel See `notification_channels` below.
        """
        return pulumi.get(self, "notification_channels")

    @notification_channels.setter
    def notification_channels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationChannelArgs']]]]):
        pulumi.set(self, "notification_channels", value)

    @property
    @pulumi.getter(name="notificationReceivers")
    def notification_receivers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationReceiverArgs']]]]:
        """
        List of alert notification recipients See `notification_receivers` below.
        """
        return pulumi.get(self, "notification_receivers")

    @notification_receivers.setter
    def notification_receivers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiAlarmRuleNotificationSettingsNotificationReceiverArgs']]]]):
        pulumi.set(self, "notification_receivers", value)


if not MYPY:
    class DiAlarmRuleNotificationSettingsNotificationChannelArgsDict(TypedDict):
        channels: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        Channel, optional enumeration value:

        Mail (Mail)

        Phone (Phone)

        Sms (Sms)

        Ding (DingTalk)
        """
        severity: NotRequired[pulumi.Input[builtins.str]]
elif False:
    DiAlarmRuleNotificationSettingsNotificationChannelArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiAlarmRuleNotificationSettingsNotificationChannelArgs:
    def __init__(__self__, *,
                 channels: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 severity: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] channels: Channel, optional enumeration value:
               
               Mail (Mail)
               
               Phone (Phone)
               
               Sms (Sms)
               
               Ding (DingTalk)
        """
        if channels is not None:
            pulumi.set(__self__, "channels", channels)
        if severity is not None:
            pulumi.set(__self__, "severity", severity)

    @property
    @pulumi.getter
    def channels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Channel, optional enumeration value:

        Mail (Mail)

        Phone (Phone)

        Sms (Sms)

        Ding (DingTalk)
        """
        return pulumi.get(self, "channels")

    @channels.setter
    def channels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "channels", value)

    @property
    @pulumi.getter
    def severity(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "severity")

    @severity.setter
    def severity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "severity", value)


if not MYPY:
    class DiAlarmRuleNotificationSettingsNotificationReceiverArgsDict(TypedDict):
        receiver_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The type of the receiver. Valid values: AliyunUid/DingToken/FeishuToken/WebHookUrl.
        """
        receiver_values: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        Receiver Value List
        """
elif False:
    DiAlarmRuleNotificationSettingsNotificationReceiverArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiAlarmRuleNotificationSettingsNotificationReceiverArgs:
    def __init__(__self__, *,
                 receiver_type: Optional[pulumi.Input[builtins.str]] = None,
                 receiver_values: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        :param pulumi.Input[builtins.str] receiver_type: The type of the receiver. Valid values: AliyunUid/DingToken/FeishuToken/WebHookUrl.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] receiver_values: Receiver Value List
        """
        if receiver_type is not None:
            pulumi.set(__self__, "receiver_type", receiver_type)
        if receiver_values is not None:
            pulumi.set(__self__, "receiver_values", receiver_values)

    @property
    @pulumi.getter(name="receiverType")
    def receiver_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the receiver. Valid values: AliyunUid/DingToken/FeishuToken/WebHookUrl.
        """
        return pulumi.get(self, "receiver_type")

    @receiver_type.setter
    def receiver_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "receiver_type", value)

    @property
    @pulumi.getter(name="receiverValues")
    def receiver_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Receiver Value List
        """
        return pulumi.get(self, "receiver_values")

    @receiver_values.setter
    def receiver_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "receiver_values", value)


if not MYPY:
    class DiAlarmRuleTriggerConditionArgsDict(TypedDict):
        ddl_report_tags: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        It takes effect only when the DDL notification is issued. The list of effective DDLs is required.
        """
        duration: NotRequired[pulumi.Input[builtins.int]]
        """
        Alarm calculation time interval, unit minute
        """
        severity: NotRequired[pulumi.Input[builtins.str]]
        """
        Severity, optional enumeration value:

        Warning

        Critical
        """
        threshold: NotRequired[pulumi.Input[builtins.int]]
        """
        Alarm threshold.

        Task status alarm: no need to fill in the threshold.

        failover alarm: The threshold is the number of failover alarms.

        Task Delay Alarm: The threshold is the delay duration, in seconds.
        """
elif False:
    DiAlarmRuleTriggerConditionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiAlarmRuleTriggerConditionArgs:
    def __init__(__self__, *,
                 ddl_report_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 duration: Optional[pulumi.Input[builtins.int]] = None,
                 severity: Optional[pulumi.Input[builtins.str]] = None,
                 threshold: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ddl_report_tags: It takes effect only when the DDL notification is issued. The list of effective DDLs is required.
        :param pulumi.Input[builtins.int] duration: Alarm calculation time interval, unit minute
        :param pulumi.Input[builtins.str] severity: Severity, optional enumeration value:
               
               Warning
               
               Critical
        :param pulumi.Input[builtins.int] threshold: Alarm threshold.
               
               Task status alarm: no need to fill in the threshold.
               
               failover alarm: The threshold is the number of failover alarms.
               
               Task Delay Alarm: The threshold is the delay duration, in seconds.
        """
        if ddl_report_tags is not None:
            pulumi.set(__self__, "ddl_report_tags", ddl_report_tags)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if severity is not None:
            pulumi.set(__self__, "severity", severity)
        if threshold is not None:
            pulumi.set(__self__, "threshold", threshold)

    @property
    @pulumi.getter(name="ddlReportTags")
    def ddl_report_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        It takes effect only when the DDL notification is issued. The list of effective DDLs is required.
        """
        return pulumi.get(self, "ddl_report_tags")

    @ddl_report_tags.setter
    def ddl_report_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ddl_report_tags", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Alarm calculation time interval, unit minute
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter
    def severity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Severity, optional enumeration value:

        Warning

        Critical
        """
        return pulumi.get(self, "severity")

    @severity.setter
    def severity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "severity", value)

    @property
    @pulumi.getter
    def threshold(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Alarm threshold.

        Task status alarm: no need to fill in the threshold.

        failover alarm: The threshold is the number of failover alarms.

        Task Delay Alarm: The threshold is the delay duration, in seconds.
        """
        return pulumi.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "threshold", value)


if not MYPY:
    class DiJobDestinationDataSourceSettingArgsDict(TypedDict):
        data_source_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Destination data source name
        """
elif False:
    DiJobDestinationDataSourceSettingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobDestinationDataSourceSettingArgs:
    def __init__(__self__, *,
                 data_source_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] data_source_name: Destination data source name
        """
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Destination data source name
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_source_name", value)


if not MYPY:
    class DiJobJobSettingsArgsDict(TypedDict):
        channel_settings: NotRequired[pulumi.Input[builtins.str]]
        """
        Channel-related task settings, in the form of a Json String.

        For example,
        {"structInfo":"MANAGED","storageType":"TEXTFILE","writeMode":"APPEND","partitionColumns":[{"columnName":"pt","columnType":"STRING","comment":""}],"fieldDelimiter":""}
        """
        column_data_type_settings: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsColumnDataTypeSettingArgsDict']]]]
        """
        Column type mapping of the synchronization task See `column_data_type_settings` below.
        """
        cycle_schedule_settings: NotRequired[pulumi.Input['DiJobJobSettingsCycleScheduleSettingsArgsDict']]
        """
        Periodic scheduling settings See `cycle_schedule_settings` below.
        """
        ddl_handling_settings: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsDdlHandlingSettingArgsDict']]]]
        """
        List of DDL processing settings for synchronization tasks See `ddl_handling_settings` below.
        """
        runtime_settings: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsRuntimeSettingArgsDict']]]]
        """
        Run-time setting parameter list See `runtime_settings` below.
        """
elif False:
    DiJobJobSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobJobSettingsArgs:
    def __init__(__self__, *,
                 channel_settings: Optional[pulumi.Input[builtins.str]] = None,
                 column_data_type_settings: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsColumnDataTypeSettingArgs']]]] = None,
                 cycle_schedule_settings: Optional[pulumi.Input['DiJobJobSettingsCycleScheduleSettingsArgs']] = None,
                 ddl_handling_settings: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsDdlHandlingSettingArgs']]]] = None,
                 runtime_settings: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsRuntimeSettingArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] channel_settings: Channel-related task settings, in the form of a Json String.
               
               For example,
               {"structInfo":"MANAGED","storageType":"TEXTFILE","writeMode":"APPEND","partitionColumns":[{"columnName":"pt","columnType":"STRING","comment":""}],"fieldDelimiter":""}
        :param pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsColumnDataTypeSettingArgs']]] column_data_type_settings: Column type mapping of the synchronization task See `column_data_type_settings` below.
        :param pulumi.Input['DiJobJobSettingsCycleScheduleSettingsArgs'] cycle_schedule_settings: Periodic scheduling settings See `cycle_schedule_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsDdlHandlingSettingArgs']]] ddl_handling_settings: List of DDL processing settings for synchronization tasks See `ddl_handling_settings` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsRuntimeSettingArgs']]] runtime_settings: Run-time setting parameter list See `runtime_settings` below.
        """
        if channel_settings is not None:
            pulumi.set(__self__, "channel_settings", channel_settings)
        if column_data_type_settings is not None:
            pulumi.set(__self__, "column_data_type_settings", column_data_type_settings)
        if cycle_schedule_settings is not None:
            pulumi.set(__self__, "cycle_schedule_settings", cycle_schedule_settings)
        if ddl_handling_settings is not None:
            pulumi.set(__self__, "ddl_handling_settings", ddl_handling_settings)
        if runtime_settings is not None:
            pulumi.set(__self__, "runtime_settings", runtime_settings)

    @property
    @pulumi.getter(name="channelSettings")
    def channel_settings(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Channel-related task settings, in the form of a Json String.

        For example,
        {"structInfo":"MANAGED","storageType":"TEXTFILE","writeMode":"APPEND","partitionColumns":[{"columnName":"pt","columnType":"STRING","comment":""}],"fieldDelimiter":""}
        """
        return pulumi.get(self, "channel_settings")

    @channel_settings.setter
    def channel_settings(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "channel_settings", value)

    @property
    @pulumi.getter(name="columnDataTypeSettings")
    def column_data_type_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsColumnDataTypeSettingArgs']]]]:
        """
        Column type mapping of the synchronization task See `column_data_type_settings` below.
        """
        return pulumi.get(self, "column_data_type_settings")

    @column_data_type_settings.setter
    def column_data_type_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsColumnDataTypeSettingArgs']]]]):
        pulumi.set(self, "column_data_type_settings", value)

    @property
    @pulumi.getter(name="cycleScheduleSettings")
    def cycle_schedule_settings(self) -> Optional[pulumi.Input['DiJobJobSettingsCycleScheduleSettingsArgs']]:
        """
        Periodic scheduling settings See `cycle_schedule_settings` below.
        """
        return pulumi.get(self, "cycle_schedule_settings")

    @cycle_schedule_settings.setter
    def cycle_schedule_settings(self, value: Optional[pulumi.Input['DiJobJobSettingsCycleScheduleSettingsArgs']]):
        pulumi.set(self, "cycle_schedule_settings", value)

    @property
    @pulumi.getter(name="ddlHandlingSettings")
    def ddl_handling_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsDdlHandlingSettingArgs']]]]:
        """
        List of DDL processing settings for synchronization tasks See `ddl_handling_settings` below.
        """
        return pulumi.get(self, "ddl_handling_settings")

    @ddl_handling_settings.setter
    def ddl_handling_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsDdlHandlingSettingArgs']]]]):
        pulumi.set(self, "ddl_handling_settings", value)

    @property
    @pulumi.getter(name="runtimeSettings")
    def runtime_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsRuntimeSettingArgs']]]]:
        """
        Run-time setting parameter list See `runtime_settings` below.
        """
        return pulumi.get(self, "runtime_settings")

    @runtime_settings.setter
    def runtime_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobJobSettingsRuntimeSettingArgs']]]]):
        pulumi.set(self, "runtime_settings", value)


if not MYPY:
    class DiJobJobSettingsColumnDataTypeSettingArgsDict(TypedDict):
        destination_data_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The destination type of the mapping relationship
        """
        source_data_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The source type of the mapping type
        """
elif False:
    DiJobJobSettingsColumnDataTypeSettingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobJobSettingsColumnDataTypeSettingArgs:
    def __init__(__self__, *,
                 destination_data_type: Optional[pulumi.Input[builtins.str]] = None,
                 source_data_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] destination_data_type: The destination type of the mapping relationship
        :param pulumi.Input[builtins.str] source_data_type: The source type of the mapping type
        """
        if destination_data_type is not None:
            pulumi.set(__self__, "destination_data_type", destination_data_type)
        if source_data_type is not None:
            pulumi.set(__self__, "source_data_type", source_data_type)

    @property
    @pulumi.getter(name="destinationDataType")
    def destination_data_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The destination type of the mapping relationship
        """
        return pulumi.get(self, "destination_data_type")

    @destination_data_type.setter
    def destination_data_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_data_type", value)

    @property
    @pulumi.getter(name="sourceDataType")
    def source_data_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The source type of the mapping type
        """
        return pulumi.get(self, "source_data_type")

    @source_data_type.setter
    def source_data_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_data_type", value)


if not MYPY:
    class DiJobJobSettingsCycleScheduleSettingsArgsDict(TypedDict):
        cycle_migration_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The type of synchronization that requires periodic scheduling. Value range:

        Full: Full

        OfflineIncremental: offline increment
        """
        schedule_parameters: NotRequired[pulumi.Input[builtins.str]]
        """
        Scheduling Parameters
        """
elif False:
    DiJobJobSettingsCycleScheduleSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobJobSettingsCycleScheduleSettingsArgs:
    def __init__(__self__, *,
                 cycle_migration_type: Optional[pulumi.Input[builtins.str]] = None,
                 schedule_parameters: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] cycle_migration_type: The type of synchronization that requires periodic scheduling. Value range:
               
               Full: Full
               
               OfflineIncremental: offline increment
        :param pulumi.Input[builtins.str] schedule_parameters: Scheduling Parameters
        """
        if cycle_migration_type is not None:
            pulumi.set(__self__, "cycle_migration_type", cycle_migration_type)
        if schedule_parameters is not None:
            pulumi.set(__self__, "schedule_parameters", schedule_parameters)

    @property
    @pulumi.getter(name="cycleMigrationType")
    def cycle_migration_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of synchronization that requires periodic scheduling. Value range:

        Full: Full

        OfflineIncremental: offline increment
        """
        return pulumi.get(self, "cycle_migration_type")

    @cycle_migration_type.setter
    def cycle_migration_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cycle_migration_type", value)

    @property
    @pulumi.getter(name="scheduleParameters")
    def schedule_parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Scheduling Parameters
        """
        return pulumi.get(self, "schedule_parameters")

    @schedule_parameters.setter
    def schedule_parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "schedule_parameters", value)


if not MYPY:
    class DiJobJobSettingsDdlHandlingSettingArgsDict(TypedDict):
        action: NotRequired[pulumi.Input[builtins.str]]
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        DDL type, optional enumeration value:

        RenameColumn (rename column)

        ModifyColumn (rename column)

        CreateTable (Rename Column)

        TruncateTable (empty table)

        DropTable (delete table)
        """
elif False:
    DiJobJobSettingsDdlHandlingSettingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobJobSettingsDdlHandlingSettingArgs:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] type: DDL type, optional enumeration value:
               
               RenameColumn (rename column)
               
               ModifyColumn (rename column)
               
               CreateTable (Rename Column)
               
               TruncateTable (empty table)
               
               DropTable (delete table)
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DDL type, optional enumeration value:

        RenameColumn (rename column)

        ModifyColumn (rename column)

        CreateTable (Rename Column)

        TruncateTable (empty table)

        DropTable (delete table)
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class DiJobJobSettingsRuntimeSettingArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        Set name, optional ENUM value:

        runtime.offline.speed.limit.mb (valid when runtime.offline.speed.limit.enable = true)

        runtime.offline.speed.limit.enable

        dst.offline.connection.max (the maximum number of write connections for offline batch tasks)

        runtime.offline.concurrent (offline batch synchronization task concurrency)

        dst.realtime.connection.max (maximum number of write connections for real-time tasks)

        runtime.enable.auto.create.schema (whether to automatically create a schema on the target side)

        src.offline.datasource.max.connection (maximum number of source connections for offline batch tasks)

        runtime.realtime.concurrent (real-time task concurrency)
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        Runtime setting value
        """
elif False:
    DiJobJobSettingsRuntimeSettingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobJobSettingsRuntimeSettingArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] name: Set name, optional ENUM value:
               
               runtime.offline.speed.limit.mb (valid when runtime.offline.speed.limit.enable = true)
               
               runtime.offline.speed.limit.enable
               
               dst.offline.connection.max (the maximum number of write connections for offline batch tasks)
               
               runtime.offline.concurrent (offline batch synchronization task concurrency)
               
               dst.realtime.connection.max (maximum number of write connections for real-time tasks)
               
               runtime.enable.auto.create.schema (whether to automatically create a schema on the target side)
               
               src.offline.datasource.max.connection (maximum number of source connections for offline batch tasks)
               
               runtime.realtime.concurrent (real-time task concurrency)
        :param pulumi.Input[builtins.str] value: Runtime setting value
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set name, optional ENUM value:

        runtime.offline.speed.limit.mb (valid when runtime.offline.speed.limit.enable = true)

        runtime.offline.speed.limit.enable

        dst.offline.connection.max (the maximum number of write connections for offline batch tasks)

        runtime.offline.concurrent (offline batch synchronization task concurrency)

        dst.realtime.connection.max (maximum number of write connections for real-time tasks)

        runtime.enable.auto.create.schema (whether to automatically create a schema on the target side)

        src.offline.datasource.max.connection (maximum number of source connections for offline batch tasks)

        runtime.realtime.concurrent (real-time task concurrency)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Runtime setting value
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class DiJobResourceSettingsArgsDict(TypedDict):
        offline_resource_settings: NotRequired[pulumi.Input['DiJobResourceSettingsOfflineResourceSettingsArgsDict']]
        """
        Offline Resource Group configuration See `offline_resource_settings` below.
        """
        realtime_resource_settings: NotRequired[pulumi.Input['DiJobResourceSettingsRealtimeResourceSettingsArgsDict']]
        """
        Real-time Resource Group See `realtime_resource_settings` below.
        """
        schedule_resource_settings: NotRequired[pulumi.Input['DiJobResourceSettingsScheduleResourceSettingsArgsDict']]
        """
        Scheduling Resource Groups See `schedule_resource_settings` below.
        """
elif False:
    DiJobResourceSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobResourceSettingsArgs:
    def __init__(__self__, *,
                 offline_resource_settings: Optional[pulumi.Input['DiJobResourceSettingsOfflineResourceSettingsArgs']] = None,
                 realtime_resource_settings: Optional[pulumi.Input['DiJobResourceSettingsRealtimeResourceSettingsArgs']] = None,
                 schedule_resource_settings: Optional[pulumi.Input['DiJobResourceSettingsScheduleResourceSettingsArgs']] = None):
        """
        :param pulumi.Input['DiJobResourceSettingsOfflineResourceSettingsArgs'] offline_resource_settings: Offline Resource Group configuration See `offline_resource_settings` below.
        :param pulumi.Input['DiJobResourceSettingsRealtimeResourceSettingsArgs'] realtime_resource_settings: Real-time Resource Group See `realtime_resource_settings` below.
        :param pulumi.Input['DiJobResourceSettingsScheduleResourceSettingsArgs'] schedule_resource_settings: Scheduling Resource Groups See `schedule_resource_settings` below.
        """
        if offline_resource_settings is not None:
            pulumi.set(__self__, "offline_resource_settings", offline_resource_settings)
        if realtime_resource_settings is not None:
            pulumi.set(__self__, "realtime_resource_settings", realtime_resource_settings)
        if schedule_resource_settings is not None:
            pulumi.set(__self__, "schedule_resource_settings", schedule_resource_settings)

    @property
    @pulumi.getter(name="offlineResourceSettings")
    def offline_resource_settings(self) -> Optional[pulumi.Input['DiJobResourceSettingsOfflineResourceSettingsArgs']]:
        """
        Offline Resource Group configuration See `offline_resource_settings` below.
        """
        return pulumi.get(self, "offline_resource_settings")

    @offline_resource_settings.setter
    def offline_resource_settings(self, value: Optional[pulumi.Input['DiJobResourceSettingsOfflineResourceSettingsArgs']]):
        pulumi.set(self, "offline_resource_settings", value)

    @property
    @pulumi.getter(name="realtimeResourceSettings")
    def realtime_resource_settings(self) -> Optional[pulumi.Input['DiJobResourceSettingsRealtimeResourceSettingsArgs']]:
        """
        Real-time Resource Group See `realtime_resource_settings` below.
        """
        return pulumi.get(self, "realtime_resource_settings")

    @realtime_resource_settings.setter
    def realtime_resource_settings(self, value: Optional[pulumi.Input['DiJobResourceSettingsRealtimeResourceSettingsArgs']]):
        pulumi.set(self, "realtime_resource_settings", value)

    @property
    @pulumi.getter(name="scheduleResourceSettings")
    def schedule_resource_settings(self) -> Optional[pulumi.Input['DiJobResourceSettingsScheduleResourceSettingsArgs']]:
        """
        Scheduling Resource Groups See `schedule_resource_settings` below.
        """
        return pulumi.get(self, "schedule_resource_settings")

    @schedule_resource_settings.setter
    def schedule_resource_settings(self, value: Optional[pulumi.Input['DiJobResourceSettingsScheduleResourceSettingsArgs']]):
        pulumi.set(self, "schedule_resource_settings", value)


if not MYPY:
    class DiJobResourceSettingsOfflineResourceSettingsArgsDict(TypedDict):
        requested_cu: NotRequired[pulumi.Input[builtins.float]]
        """
        Scheduling resource group cu
        """
        resource_group_identifier: NotRequired[pulumi.Input[builtins.str]]
        """
        Scheduling resource group name
        """
elif False:
    DiJobResourceSettingsOfflineResourceSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobResourceSettingsOfflineResourceSettingsArgs:
    def __init__(__self__, *,
                 requested_cu: Optional[pulumi.Input[builtins.float]] = None,
                 resource_group_identifier: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.float] requested_cu: Scheduling resource group cu
        :param pulumi.Input[builtins.str] resource_group_identifier: Scheduling resource group name
        """
        if requested_cu is not None:
            pulumi.set(__self__, "requested_cu", requested_cu)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)

    @property
    @pulumi.getter(name="requestedCu")
    def requested_cu(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Scheduling resource group cu
        """
        return pulumi.get(self, "requested_cu")

    @requested_cu.setter
    def requested_cu(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "requested_cu", value)

    @property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Scheduling resource group name
        """
        return pulumi.get(self, "resource_group_identifier")

    @resource_group_identifier.setter
    def resource_group_identifier(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_identifier", value)


if not MYPY:
    class DiJobResourceSettingsRealtimeResourceSettingsArgsDict(TypedDict):
        requested_cu: NotRequired[pulumi.Input[builtins.float]]
        """
        Scheduling resource group cu
        """
        resource_group_identifier: NotRequired[pulumi.Input[builtins.str]]
        """
        Scheduling resource group name
        """
elif False:
    DiJobResourceSettingsRealtimeResourceSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobResourceSettingsRealtimeResourceSettingsArgs:
    def __init__(__self__, *,
                 requested_cu: Optional[pulumi.Input[builtins.float]] = None,
                 resource_group_identifier: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.float] requested_cu: Scheduling resource group cu
        :param pulumi.Input[builtins.str] resource_group_identifier: Scheduling resource group name
        """
        if requested_cu is not None:
            pulumi.set(__self__, "requested_cu", requested_cu)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)

    @property
    @pulumi.getter(name="requestedCu")
    def requested_cu(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Scheduling resource group cu
        """
        return pulumi.get(self, "requested_cu")

    @requested_cu.setter
    def requested_cu(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "requested_cu", value)

    @property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Scheduling resource group name
        """
        return pulumi.get(self, "resource_group_identifier")

    @resource_group_identifier.setter
    def resource_group_identifier(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_identifier", value)


if not MYPY:
    class DiJobResourceSettingsScheduleResourceSettingsArgsDict(TypedDict):
        requested_cu: NotRequired[pulumi.Input[builtins.float]]
        """
        Scheduling resource group cu
        """
        resource_group_identifier: NotRequired[pulumi.Input[builtins.str]]
        """
        Scheduling resource group name
        """
elif False:
    DiJobResourceSettingsScheduleResourceSettingsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobResourceSettingsScheduleResourceSettingsArgs:
    def __init__(__self__, *,
                 requested_cu: Optional[pulumi.Input[builtins.float]] = None,
                 resource_group_identifier: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.float] requested_cu: Scheduling resource group cu
        :param pulumi.Input[builtins.str] resource_group_identifier: Scheduling resource group name
        """
        if requested_cu is not None:
            pulumi.set(__self__, "requested_cu", requested_cu)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)

    @property
    @pulumi.getter(name="requestedCu")
    def requested_cu(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Scheduling resource group cu
        """
        return pulumi.get(self, "requested_cu")

    @requested_cu.setter
    def requested_cu(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "requested_cu", value)

    @property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Scheduling resource group name
        """
        return pulumi.get(self, "resource_group_identifier")

    @resource_group_identifier.setter
    def resource_group_identifier(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_identifier", value)


if not MYPY:
    class DiJobSourceDataSourceSettingArgsDict(TypedDict):
        data_source_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Data source name of a single source
        """
        data_source_properties: NotRequired[pulumi.Input['DiJobSourceDataSourceSettingDataSourcePropertiesArgsDict']]
        """
        Single Source Data Source Properties See `data_source_properties` below.
        """
elif False:
    DiJobSourceDataSourceSettingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobSourceDataSourceSettingArgs:
    def __init__(__self__, *,
                 data_source_name: Optional[pulumi.Input[builtins.str]] = None,
                 data_source_properties: Optional[pulumi.Input['DiJobSourceDataSourceSettingDataSourcePropertiesArgs']] = None):
        """
        :param pulumi.Input[builtins.str] data_source_name: Data source name of a single source
        :param pulumi.Input['DiJobSourceDataSourceSettingDataSourcePropertiesArgs'] data_source_properties: Single Source Data Source Properties See `data_source_properties` below.
        """
        if data_source_name is not None:
            pulumi.set(__self__, "data_source_name", data_source_name)
        if data_source_properties is not None:
            pulumi.set(__self__, "data_source_properties", data_source_properties)

    @property
    @pulumi.getter(name="dataSourceName")
    def data_source_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data source name of a single source
        """
        return pulumi.get(self, "data_source_name")

    @data_source_name.setter
    def data_source_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_source_name", value)

    @property
    @pulumi.getter(name="dataSourceProperties")
    def data_source_properties(self) -> Optional[pulumi.Input['DiJobSourceDataSourceSettingDataSourcePropertiesArgs']]:
        """
        Single Source Data Source Properties See `data_source_properties` below.
        """
        return pulumi.get(self, "data_source_properties")

    @data_source_properties.setter
    def data_source_properties(self, value: Optional[pulumi.Input['DiJobSourceDataSourceSettingDataSourcePropertiesArgs']]):
        pulumi.set(self, "data_source_properties", value)


if not MYPY:
    class DiJobSourceDataSourceSettingDataSourcePropertiesArgsDict(TypedDict):
        encoding: NotRequired[pulumi.Input[builtins.str]]
        """
        Data Source Encoding
        """
        timezone: NotRequired[pulumi.Input[builtins.str]]
        """
        Data Source Time Zone
        """
elif False:
    DiJobSourceDataSourceSettingDataSourcePropertiesArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobSourceDataSourceSettingDataSourcePropertiesArgs:
    def __init__(__self__, *,
                 encoding: Optional[pulumi.Input[builtins.str]] = None,
                 timezone: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] encoding: Data Source Encoding
        :param pulumi.Input[builtins.str] timezone: Data Source Time Zone
        """
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)

    @property
    @pulumi.getter
    def encoding(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data Source Encoding
        """
        return pulumi.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "encoding", value)

    @property
    @pulumi.getter
    def timezone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data Source Time Zone
        """
        return pulumi.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "timezone", value)


if not MYPY:
    class DiJobTableMappingArgsDict(TypedDict):
        source_object_selection_rules: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingSourceObjectSelectionRuleArgsDict']]]]
        """
        Each rule can select different types of source objects to be synchronized, such as source database and source data table. See `source_object_selection_rules` below.
        """
        transformation_rules: NotRequired[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingTransformationRuleArgsDict']]]]
        """
        A list of conversion rule definitions for a synchronization object. Each element in the list defines a conversion rule. See `transformation_rules` below.
        """
elif False:
    DiJobTableMappingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobTableMappingArgs:
    def __init__(__self__, *,
                 source_object_selection_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingSourceObjectSelectionRuleArgs']]]] = None,
                 transformation_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingTransformationRuleArgs']]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingSourceObjectSelectionRuleArgs']]] source_object_selection_rules: Each rule can select different types of source objects to be synchronized, such as source database and source data table. See `source_object_selection_rules` below.
        :param pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingTransformationRuleArgs']]] transformation_rules: A list of conversion rule definitions for a synchronization object. Each element in the list defines a conversion rule. See `transformation_rules` below.
        """
        if source_object_selection_rules is not None:
            pulumi.set(__self__, "source_object_selection_rules", source_object_selection_rules)
        if transformation_rules is not None:
            pulumi.set(__self__, "transformation_rules", transformation_rules)

    @property
    @pulumi.getter(name="sourceObjectSelectionRules")
    def source_object_selection_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingSourceObjectSelectionRuleArgs']]]]:
        """
        Each rule can select different types of source objects to be synchronized, such as source database and source data table. See `source_object_selection_rules` below.
        """
        return pulumi.get(self, "source_object_selection_rules")

    @source_object_selection_rules.setter
    def source_object_selection_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingSourceObjectSelectionRuleArgs']]]]):
        pulumi.set(self, "source_object_selection_rules", value)

    @property
    @pulumi.getter(name="transformationRules")
    def transformation_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingTransformationRuleArgs']]]]:
        """
        A list of conversion rule definitions for a synchronization object. Each element in the list defines a conversion rule. See `transformation_rules` below.
        """
        return pulumi.get(self, "transformation_rules")

    @transformation_rules.setter
    def transformation_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiJobTableMappingTransformationRuleArgs']]]]):
        pulumi.set(self, "transformation_rules", value)


if not MYPY:
    class DiJobTableMappingSourceObjectSelectionRuleArgsDict(TypedDict):
        action: NotRequired[pulumi.Input[builtins.str]]
        expression: NotRequired[pulumi.Input[builtins.str]]
        """
        Expression, such as mysql_table_1
        """
        expression_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Expression type, value range: Exact/Regex
        """
        object_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Object type, optional enumeration value:

        Table (Table)

        Database
        """
elif False:
    DiJobTableMappingSourceObjectSelectionRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobTableMappingSourceObjectSelectionRuleArgs:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[builtins.str]] = None,
                 expression: Optional[pulumi.Input[builtins.str]] = None,
                 expression_type: Optional[pulumi.Input[builtins.str]] = None,
                 object_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] expression: Expression, such as mysql_table_1
        :param pulumi.Input[builtins.str] expression_type: Expression type, value range: Exact/Regex
        :param pulumi.Input[builtins.str] object_type: Object type, optional enumeration value:
               
               Table (Table)
               
               Database
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if expression_type is not None:
            pulumi.set(__self__, "expression_type", expression_type)
        if object_type is not None:
            pulumi.set(__self__, "object_type", object_type)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def expression(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Expression, such as mysql_table_1
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter(name="expressionType")
    def expression_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Expression type, value range: Exact/Regex
        """
        return pulumi.get(self, "expression_type")

    @expression_type.setter
    def expression_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expression_type", value)

    @property
    @pulumi.getter(name="objectType")
    def object_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Object type, optional enumeration value:

        Table (Table)

        Database
        """
        return pulumi.get(self, "object_type")

    @object_type.setter
    def object_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "object_type", value)


if not MYPY:
    class DiJobTableMappingTransformationRuleArgsDict(TypedDict):
        rule_action_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Action type, optional enumeration value:

        DefinePrimaryKey (defines the primary key)

        Rename

        AddColumn (increase column)

        HandleDml(DML handling)

        DefineIncrementalCondition
        """
        rule_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Rule Name
        """
        rule_target_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Target type of action, optional enumeration value:

        Table (Table)

        Schema(schema)
        """
elif False:
    DiJobTableMappingTransformationRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobTableMappingTransformationRuleArgs:
    def __init__(__self__, *,
                 rule_action_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_target_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] rule_action_type: Action type, optional enumeration value:
               
               DefinePrimaryKey (defines the primary key)
               
               Rename
               
               AddColumn (increase column)
               
               HandleDml(DML handling)
               
               DefineIncrementalCondition
        :param pulumi.Input[builtins.str] rule_name: Rule Name
        :param pulumi.Input[builtins.str] rule_target_type: Target type of action, optional enumeration value:
               
               Table (Table)
               
               Schema(schema)
        """
        if rule_action_type is not None:
            pulumi.set(__self__, "rule_action_type", rule_action_type)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_target_type is not None:
            pulumi.set(__self__, "rule_target_type", rule_target_type)

    @property
    @pulumi.getter(name="ruleActionType")
    def rule_action_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Action type, optional enumeration value:

        DefinePrimaryKey (defines the primary key)

        Rename

        AddColumn (increase column)

        HandleDml(DML handling)

        DefineIncrementalCondition
        """
        return pulumi.get(self, "rule_action_type")

    @rule_action_type.setter
    def rule_action_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_action_type", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule Name
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleTargetType")
    def rule_target_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Target type of action, optional enumeration value:

        Table (Table)

        Schema(schema)
        """
        return pulumi.get(self, "rule_target_type")

    @rule_target_type.setter
    def rule_target_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_target_type", value)


if not MYPY:
    class DiJobTransformationRuleArgsDict(TypedDict):
        rule_action_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Action type, optional enumeration value:

        DefinePrimaryKey (defines the primary key)

        Rename

        AddColumn (increase column)

        HandleDml(DML handling)

        DefineIncrementalCondition
        """
        rule_expression: NotRequired[pulumi.Input[builtins.str]]
        """
        Regular expression, in json string format.

        Example renaming rule (Rename): {"expression":"${srcDatasourceName}_${srcDatabaseName}_0922","variables":[{"variableName":"srcDatabaseName","variableRules":[{"from":"fromdb","to":"todb"}]}]}
        """
        rule_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Rule Name
        """
        rule_target_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Target type of action, optional enumeration value:

        Table (Table)

        Schema(schema)
        """
elif False:
    DiJobTransformationRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DiJobTransformationRuleArgs:
    def __init__(__self__, *,
                 rule_action_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule_expression: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_target_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] rule_action_type: Action type, optional enumeration value:
               
               DefinePrimaryKey (defines the primary key)
               
               Rename
               
               AddColumn (increase column)
               
               HandleDml(DML handling)
               
               DefineIncrementalCondition
        :param pulumi.Input[builtins.str] rule_expression: Regular expression, in json string format.
               
               Example renaming rule (Rename): {"expression":"${srcDatasourceName}_${srcDatabaseName}_0922","variables":[{"variableName":"srcDatabaseName","variableRules":[{"from":"fromdb","to":"todb"}]}]}
        :param pulumi.Input[builtins.str] rule_name: Rule Name
        :param pulumi.Input[builtins.str] rule_target_type: Target type of action, optional enumeration value:
               
               Table (Table)
               
               Schema(schema)
        """
        if rule_action_type is not None:
            pulumi.set(__self__, "rule_action_type", rule_action_type)
        if rule_expression is not None:
            pulumi.set(__self__, "rule_expression", rule_expression)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_target_type is not None:
            pulumi.set(__self__, "rule_target_type", rule_target_type)

    @property
    @pulumi.getter(name="ruleActionType")
    def rule_action_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Action type, optional enumeration value:

        DefinePrimaryKey (defines the primary key)

        Rename

        AddColumn (increase column)

        HandleDml(DML handling)

        DefineIncrementalCondition
        """
        return pulumi.get(self, "rule_action_type")

    @rule_action_type.setter
    def rule_action_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_action_type", value)

    @property
    @pulumi.getter(name="ruleExpression")
    def rule_expression(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Regular expression, in json string format.

        Example renaming rule (Rename): {"expression":"${srcDatasourceName}_${srcDatabaseName}_0922","variables":[{"variableName":"srcDatabaseName","variableRules":[{"from":"fromdb","to":"todb"}]}]}
        """
        return pulumi.get(self, "rule_expression")

    @rule_expression.setter
    def rule_expression(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_expression", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule Name
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleTargetType")
    def rule_target_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Target type of action, optional enumeration value:

        Table (Table)

        Schema(schema)
        """
        return pulumi.get(self, "rule_target_type")

    @rule_target_type.setter
    def rule_target_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_target_type", value)


if not MYPY:
    class ProjectMemberRoleArgsDict(TypedDict):
        code: NotRequired[pulumi.Input[builtins.str]]
        """
        Project Role Code.
        """
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        project role name
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        project role type
        """
elif False:
    ProjectMemberRoleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ProjectMemberRoleArgs:
    def __init__(__self__, *,
                 code: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] code: Project Role Code.
        :param pulumi.Input[builtins.str] name: project role name
        :param pulumi.Input[builtins.str] type: project role type
        """
        if code is not None:
            pulumi.set(__self__, "code", code)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Project Role Code.
        """
        return pulumi.get(self, "code")

    @code.setter
    def code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "code", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        project role name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        project role type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


